#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os
import sys

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import detector
import installer 

def detect():
    if detector.is_flatpak_installed():
        print("✅ Flatpak is already installed.")
        return True
    else:
        print("❌ Flatpak is not installed.")
        return False
def detect_flathub():
    if detector.is_flathub_added():
        print("✅ Flathub is already added.")
        return True
    else:
        print("❌ Flathub is not added.")
        return False

# flatpak detector.py - This file contains methods to detect if flatpak is installed.
# It checks various conditions to determine
# If any of this method returns True, then flatpak is considered installed.
# Methods:
# Method 1: Check if 'flatpak' is in PATH   
# Method 2: Try running 'flatpak --version'
# Method 3: Check if flatpak executable is accessible and executable

# It also supports to check is flathub added or not.
# It checks via `flatpak remotes` command and known repo file paths.
# If any of this method returns True, then flathub is considered added.

def install(password):
    return installer.install_flatpak(password)

def install_flathub(password):
    return installer.install_flathub(password)

# flatpak installer.py - This file contains methods to install flatpak.
# It uses subprocess to run the installation command.   
# It uses the system's package manager to install flatpak.
# It returns True if installation is successful, otherwise False.
# It also supports to install flathub repository.
# It uses the system's package manager to install flathub.
# It returns True if installation is successful, otherwise False.
# Even though it return false or True - Must check, is it correct using detector.py after installation.
# It wants user password to run sudo commands.(due to it needs sudo privileges to install packages)


#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import sys
import os

def get_package_manager():
    for pm in ["apt", "dnf", "yum", "pacman", "zypper"]:
        if shutil.which(pm):
            return pm
    return None

def run_sudo_command(command, password):
    try:
        result = subprocess.run(
            ["sudo", "-S"] + command,
            input=password + "\n",
            text=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE
        )
        return result.returncode == 0
    except Exception:
        return False

def post_install_snapd(password):
    """Enable snapd service and fix /snap link if needed."""
    run_sudo_command(["systemctl", "enable", "--now", "snapd.socket"], password)

    # For distros without /snap link
    if not os.path.exists("/snap"):
        run_sudo_command(["ln", "-s", "/var/lib/snapd/snap", "/snap"], password)

    # For openSUSE-specific apparmor unit
    if os.path.exists("/usr/lib/systemd/system/snapd.apparmor.service"):
        run_sudo_command(["systemctl", "enable", "--now", "snapd.apparmor"], password)

def install_package(pkg_name, password):
    pm = get_package_manager()
    if not pm:
        print("❌ No supported package manager found.")
        return False

    print(f"📦 Installing {pkg_name} using {pm}...")

    try:
        if pm == "apt":
            run_sudo_command(["apt", "update"], password)
            success = run_sudo_command(["apt", "install", "-y", pkg_name], password)

        elif pm == "dnf":
            success = run_sudo_command(["dnf", "install", "-y", pkg_name], password)

        elif pm == "yum":
            success = run_sudo_command(["yum", "install", "-y", pkg_name], password)

        elif pm == "pacman":
            success = run_sudo_command(["pacman", "-Sy", pkg_name, "--noconfirm"], password)

        elif pm == "zypper":
            success = run_sudo_command(["zypper", "install", "-y", pkg_name], password)

        else:
            success = False

        # Post-install actions for snapd
        if success and pkg_name == "snapd":
            post_install_snapd(password)

        return success

    except subprocess.CalledProcessError:
        print(f"❌ Failed to install {pkg_name} using {pm}.")
        return False

def install_snapd(password):
    """Install snapd package."""
    if not install_package("snapd", password):
        print("❌ Failed to install snapd.")
        return False

    print("✅ snapd installed successfully.")
    return True

def install_snap_store(password):
    try:
        # Install snap-store
        result = subprocess.run(
            ["sudo", "-S", "snap", "install", "snap-store"],
            input=password + "\n",
            text=True
        )
        if result.returncode == 0:
            print("✅ Snap Store installed successfully.")
            return True
        else:
            print("❌ Failed to install Snap Store.")
            return False

    except Exception as e:
        print(f"❌ Error: {e}")
        return False


#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os

def is_snapd_installed():
    # Method 1: Check if snap command is available
    method_which = shutil.which("snap") is not None

    # Method 2: Try running 'snap version'
    try:
        method_version = subprocess.run(
            ["snap", "version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        ).returncode == 0
    except Exception:
        method_version = False

    # Method 3: Check for snapd service file (systemd based)
    method_service = os.path.exists("/lib/systemd/system/snapd.service") or \
                     os.path.exists("/etc/systemd/system/snapd.service")

    return method_which or method_version or method_service


def is_snap_app_installed(app_name):
    if not is_snapd_installed():
        return False

    try:
        result = subprocess.run(
            ["snap", "list"],
            check=True,
            capture_output=True,
            text=True
        )
        return app_name.lower() in result.stdout.lower()
    except Exception:
        return False
    

def check_snapd():
    if is_snapd_installed():
        print("✅ snapd is installed and working.")
        return True
    else:
        print("❌ snapd is not available.")
        return False

def check_snap_store():
    if is_snap_app_installed("snap-store"):
        print("✅ snap-store is installed via Snap.")
        return True
    else:
        print("❌ snap-store is not installed via Snap.")
        return False




#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os
import sys

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import detector
import installer 
import depresolver

def detect():
    if detector.is_sdkman_installed():
        return True
    else:
        return False



# sdkman dectector.py - This file contains methods to detect if SDKMAN is installed.
# It checks various conditions to determine
# If any of this method returns True, then SDKMAN is considered installed.
# Methods:
# Method 1: Check if 'sdk' is in PATH
# Method 2: Try running 'sdk version'
# Method 3: Check if SDKMAN directory exists
# Method 4: Check if sdk script is executable (from previous found)
# Method 5: Check environment variable(checks valid)

def install():
    return installer.install_sdkman()

# sdkman installer.py - This file contains methods to install SDKMAN.
# It uses subprocess to run the installation command.
# It uses curl to download and execute the installation script.
# It returns True if installation is successful, otherwise False.

# Even though it return false or True - Must check, is it correct using detector.py after installation.


def depresolve(password):
    return depresolver.install_dependencies(password)

# sdkman depresolver.py - This file contains methods to resolve dependencies.
# It install curl,zip,unzip,bash which is required by SDKMAN.
# It uses the system's package manager to install these dependencies.
# It checks is it already installed but only uses the shutil.which method.
# It wants user password to run sudo commands.(due to it needs sudo privileges to install packages)


#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import sys
import os

def get_package_manager():
    for pm in ["apt", "dnf", "yum", "pacman", "zypper"]:
        if shutil.which(pm):
            return pm
    return None

def run_sudo_command(command, password):
    try:
        result = subprocess.run(
            ["sudo", "-S"] + command,
            input=password + "\n",
            text=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        )
        return result.returncode == 0
    except Exception:
        return False

def install_package(pkg_name, password):
    pm = get_package_manager()
    if not pm:
        print("❌ No supported package manager found (APT, DNF, YUM, PACMAN, ZYPPER).")
        return False

    print(f"📦 Installing {pkg_name} using {pm}...")

    try:
        if pm == "apt":
            run_sudo_command(["apt", "update"], password)
            return run_sudo_command(["apt", "install", "-y", pkg_name], password)

        elif pm == "dnf":
            return run_sudo_command(["dnf", "install", "-y", pkg_name], password)

        elif pm == "yum":
            return run_sudo_command(["yum", "install", "-y", pkg_name], password)

        elif pm == "pacman":
            return run_sudo_command(["pacman", "-Sy", pkg_name, "--noconfirm"], password)

        elif pm == "zypper":
            return run_sudo_command(["zypper", "install", "-y", pkg_name], password)

    except subprocess.CalledProcessError:
        print(f"❌ Failed to install {pkg_name} using {pm}.")
        return False


def install_curl_if_missing(password):
    if shutil.which("curl") is None:
        if install_package("curl", password):
            print("✅ curl installed successfully.")
            return True
        else:
            print("❌ curl installation failed.")
            return False
    print("✅ curl is already installed.")
    return True

def install_wget_if_missing(password):
    if shutil.which("wget") is None:
        if install_package("wget", password):
            print("✅ wget installed successfully.")
            return True
        else:
            print("❌ wget installation failed.")
            return False
    print("✅ wget is already installed.")
    return True

def install_gpg_if_missing(password):
        pkg_name = "gnupg"
        if install_package(pkg_name, password):
            print("✅ GPG (gnupg) installed successfully.")
            return True
        else:
            print("❌ GPG (gnupg) installation failed.")
            return False



#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os
import sys

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import detector
import installer 

def detect_curl():
    if detector.is_curl_installed():
        print("✅ curl is already installed.")
        return True
    else:
        print("❌ curl is not installed.")
        return False
def detect_wget():  
    if detector.is_wget_installed():
        print("✅ wget is already installed.")
        return True
    else:
        print("❌ wget is not installed.")
        return False
def detect_gpg():
    if detector.is_gpg_installed():
        print("✅ gpg is already installed.")
        return True
    else:
        print("❌ gpg is not installed.")
        return False

# curl,wget,gpg detector.py - This script detects if curl, wget, and gpg are installed on the system.
# It checks curl, wget, and gpg using multiple methods,if any of the methods succeed, it considers the tool installed.
# Methods:
# 1. Check if the tool is in PATH using shutil.which.
# 2. Try running the tool with a version command (e.g., curl --version)
# 3. Check if the binary is executable using os.access.

def install_curl(password):
    return installer.install_curl_if_missing(password)
 
def install_wget(password):
    return installer.install_wget_if_missing(password)

def install_gpg(password):
    return installer.install_gpg_if_missing(password)

# curl,wget,gpg installer.py - This script installs curl, wget, and gpg using the system's package manager.
# It detects the package manager (APT, DNF, YUM, PACMAN, ZYPPER) and installs the required packages.
# it have basic checking for the package manager and handles errors during installation.
# better to check using detector.py,even if it return True or False.
# Install function of gpg doesnt have basic checking of preinstalled gpg.


#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import os
import subprocess
import shutil

def is_sdkman_installed():
    # Method 1: Check if 'sdk' is in PATH
    sdk_in_path = shutil.which("sdk") is not None

    # Method 2: Try running 'sdk version'
    try:
        result = subprocess.run(
            ["sdk", "version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        )
        sdk_version_works = result.returncode == 0
    except Exception:
        sdk_version_works = False

    # Method 3: Check if SDKMAN directory exists
    sdkman_dir = os.path.expanduser("~/.sdkman")
    sdkman_dir_exists = os.path.isdir(sdkman_dir)

    # Method 4: Check if sdk script is executable
    sdk_script_path = os.path.join(sdkman_dir, "bin", "sdk")
    sdk_script_executable = os.path.isfile(sdk_script_path) and os.access(sdk_script_path, os.X_OK)

    # Method 5: Check environment variable
    sdkman_env_var = "SDKMAN_DIR" in os.environ
    sdkman_env_path = os.environ.get("SDKMAN_DIR", "")
    sdkman_env_valid = os.path.isfile(os.path.join(sdkman_env_path, "bin", "sdk")) if sdkman_env_var else False

    # Final result: return True if any method worked
    return any([
        sdk_in_path,
        sdk_version_works,
        sdkman_dir_exists,
        sdk_script_executable,
        sdkman_env_valid
    ])



#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import os
import subprocess
import shutil

def is_curl_installed():
    # Method 1: Check if 'curl' is in PATH
    curl_path = shutil.which("curl")
    method_which = curl_path is not None

    # Method 2: Try running 'curl --version'
    try:
        result = subprocess.run(
            ["curl", "--version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        )
        method_version = result.returncode == 0
    except Exception:
        method_version = False

    # Method 3: Check if binary is executable
    method_executable = os.access(curl_path, os.X_OK) if curl_path else False

    return method_which or method_version or method_executable


def is_wget_installed():
    # Method 1: Check if 'wget' is in PATH
    wget_path = shutil.which("wget")
    method_which = wget_path is not None

    # Method 2: Try running 'wget --version'
    try:
        result = subprocess.run(
            ["wget", "--version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        )
        method_version = result.returncode == 0
    except Exception:
        method_version = False

    # Method 3: Check if binary is executable
    method_executable = os.access(wget_path, os.X_OK) if wget_path else False

    return method_which or method_version or method_executable
def is_gpg_installed():
    # Check for gpg or gpg2 in PATH
    gpg_path = shutil.which("gpg") or shutil.which("gpg2")
    method_which = gpg_path is not None

    # Try running 'gpg --version'
    try:
        result = subprocess.run(
            [gpg_path or "gpg", "--version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        )
        method_version = result.returncode == 0
    except Exception:
        method_version = False

    # Check if the binary is executable
    method_executable = os.access(gpg_path, os.X_OK) if gpg_path else False
    return method_which or method_version or method_executable





#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess

def install_sdkman():
    try:
        subprocess.run(
            'curl -s "https://get.sdkman.io" | bash',
            shell=True,
            check=True
        )
        print("✅ SDKMAN installed successfully.")
        print("🔁 Please restart your shell or run:\n   source \"$HOME/.sdkman/bin/sdkman-init.sh\"")
        return True
    except subprocess.CalledProcessError as e:
        print("❌ Failed to install SDKMAN.")
        print("Error:", e)
        return False




#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os

def is_flatpak_installed():
    method_which = shutil.which("flatpak") is not None

    try:
        method_version = subprocess.run(
            ["flatpak", "--version"],
            check=True,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL
        ).returncode == 0
    except Exception:
        method_version = False

    flatpak_path = shutil.which("flatpak")
    method_executable = os.access(flatpak_path, os.X_OK) if flatpak_path else False

    # Final result: true if any method is true
    return method_which or method_version or method_executable


def is_flathub_added():
    if not is_flatpak_installed():
        return False

    # Method 1: check via `flatpak remotes`
    try:
        result = subprocess.run(
            ["flatpak", "remotes"],
            check=True,
            capture_output=True,
            text=True
        )
        method_remote = "flathub" in result.stdout.lower()
    except Exception:
        method_remote = False

    # Method 2: check via known repo file paths
    known_paths = [
        "/etc/flatpak/remotes.d/flathub.flatpakrepo",
        "/var/lib/flatpak/repo/flathub",
        os.path.expanduser("~/.local/share/flatpak/repo/flathub")
    ]
    method_path_exists = any(os.path.exists(p) for p in known_paths)

    # Final result: true if any method is true
    return method_remote or method_path_exists




from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()
setup(
    name="argophor",
    version="0.0.1a8",
    author="Muhammed Shafin P",
    author_email="hejhdiss@gmail.com",
    description="Argophor - detection and install helper tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hejhdiss/argophor",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Other/Proprietary License",
        "Operating System :: POSIX :: Linux",
    ],
    python_requires='>=3.6',
    license="Argophor License 1.0",
    license_files=('LICENSE',),
)



#!/usr/bin/env python3

# Copyright (c) 2025 Muhammed Shafin P (hejhdiss)
# All rights reserved.

import subprocess
import shutil
import os
import sys

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import detector
import installer 

def detect():
    return detector.check_snapd()

def detect_store():
    return detector.check_snap_store()

# snap dectector.py - This file contains methods to detect if snapd is installed.
# It checks various conditions to determine 
# If any of this method returns True, then snapd is considered installed.
# Methods:  
# Method 1: Check if snap command is available
# Method 2: Try running 'snap version'          
# Method 3: Check for snapd service file (systemd based)

# It also checks snap-store app is installed via Snap.
# It inside check is snap installed as per above said methods.

def install(password):
    return installer.install_snapd(password)

def install_store(password):
    return installer.install_snap_store(password)

# snap installer.py - This file contains methods to install snapd.
# It uses subprocess to run the installation command.   
# It uses the system's package manager to install snapd.
# It returns True if installation is successful, otherwise False.   
# It also installs snap-store app if requested.
# It uses the snap to install snap-store app.
# Better to use detector.py to check if snap-store or snap is installed after installation.
# Also use detector.py to check is snapd presnt or not before snap-store installation.
# It have some post-installation steps like enabling snapd service and creating /snap link if needed.